# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.12",
        python_install_dir=r"/usr/lib/python3/dist-packages/",
        python_path=r"/usr/bin/python3.12",

        # Package versions
        contourpy_version="1.2.1",
        meson_version="1.5.1",
        mesonpy_version="0.16.0",
        pybind11_version="2.12.0",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"/build/reproducible-path/contourpy-1.2.1/.mesonpy-_ksgmaci/lib/contourpy/util",
        source_dir=r"/build/reproducible-path/contourpy-1.2.1/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dprefix=/usr -Dlibdir=lib/arm-linux-gnueabi -Dlocalstatedir=/var -Dsysconfdir=/etc -Dwrap_mode=nodownload -Dvsenv=True --native-file=/build/reproducible-path/contourpy-1.2.1/.mesonpy-_ksgmaci/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="True",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="gcc",
        compiler_version="14.2.0",
        linker_id="ld.bfd",
        compile_command="c++",

        # Host machine
        host_cpu="armv8l",
        host_cpu_family="arm",
        host_cpu_endian="little",
        host_cpu_system="linux",

        # Build machine, same as host machine if not a cross_build
        build_cpu="armv8l",
        build_cpu_family="arm",
        build_cpu_endian="little",
        build_cpu_system="linux",
    )
